pub struct ATTRIBUTE_CLASS { /* private fields */ }Methods from Deref<Target = QualName>
Sourcepub fn expanded(&self) -> ExpandedName<'_>
pub fn expanded(&self) -> ExpandedName<'_>
Take a reference of self as an ExpandedName, dropping the unresolved prefix.
In XML and HTML prefixes are only used to extract the relevant namespace URI. Expanded name only contains resolved namespace and tag name, which are only relevant parts of an XML or HTML tag and attribute name respectively.
In lieu of our XML Namespace example
<furn:table> <!-- namespace url is https://furniture.rs -->For it the expanded name would become roughly equivalent to:
ExpandedName {
ns: "https://furniture.rs",
local: "table",
}Trait Implementations
Sourceimpl Deref for ATTRIBUTE_CLASS
impl Deref for ATTRIBUTE_CLASS
impl LazyStatic for ATTRIBUTE_CLASS